Learn R Programming

SMFI5 (version 1.0)

num.jacobian: Compute the symmetric numerical first order derivatives of a multivariate function.

Description

Compute the symmetric numerical first order derivatives of a multivariate function.

Usage

num.jacobian(fct_handle, x, prec)

Arguments

fct_handle
Name of a function returning a N x 1 vector.
x
Point (d x 1) of evaluation at which the derivatives will be computed.
prec
Percentage of +\- around x (in fraction).

Value

J
Derivatives (N x d)

References

Appendix B of 'Statistical Methods for Financial Engineering, B. Remillard, CRC Press, (2013).

Examples

Run this code
data(data.cir)
out = est.cir(data.cir,method='num')

Run the code above in your browser using DataLab